(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     53823,       1127]
NotebookOptionsPosition[     52046,       1089]
NotebookOutlinePosition[     52930,       1116]
CellTagsIndexPosition[     52887,       1113]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook implements Algorithm 1 from \[OpenCurlyDoubleQuote]",
 ButtonBox["Contextuality without access to a tomographically complete set",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1904.08699"], None},
  ButtonNote->"https://arxiv.org/abs/1904.08699"],
 "\[CloseCurlyDoubleQuote] by Matthew F. Pusey, L\[IAcute]dia del Rio and \
Bettina Meyer. If you want to use the CDD interface to do vertex enumeration, \
you should first run ",
 ButtonBox["cdd_interface.nb",
  BaseStyle->"Hyperlink",
  ButtonData->{"cdd_interface.nb", None}],
 ".\n",
 StyleBox["\[Copyright] 2021 Matthew F. Pusey\nPermission is hereby granted, \
free of charge, to any person obtaining a copy of this software and \
associated documentation files (the \[OpenCurlyDoubleQuote]Software\
\[CloseCurlyDoubleQuote]), to deal in the Software without restriction, \
including without limitation the rights to use, copy, modify, merge, publish, \
distribute, sublicense, and/or sell copies of the Software, and to permit \
persons to whom the Software is furnished to do so, subject to the following \
conditions:\nThe above copyright notice and this permission notice shall be \
included in all copies or substantial portions of the Software.\nTHE SOFTWARE \
IS PROVIDED \[OpenCurlyDoubleQuote]AS IS\[CloseCurlyDoubleQuote], WITHOUT \
WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE \
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND \
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE \
FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, \
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR \
THE USE OR OTHER DEALINGS IN THE SOFTWARE.",
  FontSize->8]
}], "Text",
 CellChangeTimes->{{3.837857015822462*^9, 3.837857090546006*^9}, {
  3.83785713708144*^9, 3.8378571627079773`*^9}, {3.8378572851225843`*^9, 
  3.8378572932346582`*^9}, {3.837857443204524*^9, 3.837857445076305*^9}, {
  3.837857967676592*^9, 3.837857967680051*^9}, {3.837859167105693*^9, 
  3.837859230822208*^9}, {3.837859327811202*^9, 3.837859327812366*^9}, {
  3.837859387243493*^9, 3.837859397387397*^9}, {3.838189935322712*^9, 
  3.838189937036665*^9}},ExpressionUUID->"371bfb14-4a9c-465e-b223-\
79a5729a2fe7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"As", " ", "an", " ", "example"}], ",", " ", 
    RowBox[{
    "generate", " ", "some", " ", "stats", " ", "for", " ", "a", " ", 
     "qubit"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", "=", "5"}], ";", 
    RowBox[{"\[Eta]", "=", "0.89"}], ";", 
    RowBox[{"points", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Eta]", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
          RowBox[{"\[Eta]", " ", 
           RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], "}"}], "/.", 
        RowBox[{"\[Theta]", "\[Rule]", 
         RowBox[{"2", "\[Pi]", 
          FractionBox[
           RowBox[{"x", "+", 
            RowBox[{"1", "/", "4"}]}], "n"]}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{
    "Bloch", " ", "vectors", " ", "of", " ", "n", " ", "states", " ", 
     RowBox[{"(", 
      RowBox[{"X", " ", "and", " ", "Z", " ", "components", " ", "only"}], 
      ")"}]}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"meas", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"3", 
           RowBox[{"\[Pi]", "/", "10"}]}], "]"}], ",", 
         RowBox[{"Cos", "[", 
          RowBox[{"3", 
           RowBox[{"\[Pi]", "/", "10"}]}], "]"}]}], "}"}]}], "}"}]}], ";"}], 
   " ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Bloch", " ", "vectors", " ", "of", " ", "measurement", " ", 
     "projectors"}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"RegionPlot", "[", 
      RowBox[{
       RowBox[{"And", "@@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "\[LessEqual]", 
            RowBox[{"#", ".", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y"}], "}"}]}], "\[LessEqual]", "1"}], "&"}], 
          "/@", "meas"}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"Circle", "[", "]"}]}], "}"}], ",", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{"#2", ",", "#1"}], "]"}], "&"}], ",", "points"}], "]"}]}],
        "}"}], "]"}]}], "]"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Show", " ", "the", " ", "polygon", " ", "where", " ", "the", " ", 
      "measurements", " ", "in", " ", "meas", " ", "would", " ", "give", " ", 
      "valid", " ", "probabilities"}], ",", " ", 
     RowBox[{"the", " ", "Bloch", " ", "sphere"}], ",", " ", 
     RowBox[{"and", " ", "the", " ", "states", " ", "as", " ", "numbers"}]}], 
    " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"stats", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"r", ".", "p"}], "+", "1"}], "2"], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "points"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "meas"}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{
    "Calculate", " ", "the", " ", "probability", " ", "of", " ", "each", " ", 
     "measurement", " ", "outcome", " ", "for", " ", "each", " ", "state"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Labeled", "[", 
    RowBox[{
     RowBox[{"MatrixForm", "[", "stats", "]"}], ",", "\"\<stats =\>\"", ",", 
     "Left"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.673287122356592*^9, 3.6732871240899*^9}, 
   3.673287188204599*^9, {3.6786400665085278`*^9, 3.6786401150763283`*^9}, {
   3.678724120194044*^9, 3.67872414804353*^9}, {3.678724179432926*^9, 
   3.678724270614427*^9}, {3.678725408299712*^9, 3.678725410859355*^9}, 
   3.678725493466713*^9, {3.678725826692834*^9, 3.678725839140059*^9}, {
   3.678726116519354*^9, 3.678726202766008*^9}, {3.678726294804503*^9, 
   3.678726295795745*^9}, {3.678726364659532*^9, 3.678726496768457*^9}, {
   3.6787265986230993`*^9, 3.678726626742275*^9}, {3.6787266599906197`*^9, 
   3.678726729282628*^9}, {3.678726773204405*^9, 3.678726884828381*^9}, {
   3.678726941553007*^9, 3.678727099494748*^9}, {3.67872734080306*^9, 
   3.678727395136943*^9}, {3.678727518383745*^9, 3.6787275289116697`*^9}, {
   3.678727599607327*^9, 3.678727657549728*^9}, {3.6787348983163967`*^9, 
   3.67873491489746*^9}, {3.6787351100548487`*^9, 3.6787351122712803`*^9}, {
   3.6787352436040697`*^9, 3.678735247396289*^9}, {3.678735835699205*^9, 
   3.6787358936690493`*^9}, {3.6787360102873373`*^9, 3.678736031950247*^9}, {
   3.678736121304267*^9, 3.678736124016081*^9}, {3.6787362450920267`*^9, 
   3.6787363172666903`*^9}, 3.678736449439355*^9, 3.678736962040102*^9, {
   3.6787370180867577`*^9, 3.678737020574108*^9}, {3.678737056302307*^9, 
   3.678737059804852*^9}, {3.678737350455921*^9, 3.67873735331175*^9}, 
   3.67880746552071*^9, {3.678809210221643*^9, 3.6788092114977713`*^9}, {
   3.678809287725893*^9, 3.678809323238372*^9}, {3.67881001996911*^9, 
   3.678810044743703*^9}, {3.721648260209261*^9, 3.721648297274926*^9}, {
   3.721648337632197*^9, 3.721648395820299*^9}, 3.8336292749682703`*^9, {
   3.833629369883617*^9, 3.833629372264571*^9}, 3.8336294234345417`*^9, {
   3.833629527210672*^9, 3.833629560432736*^9}, {3.833629746699175*^9, 
   3.833629748385584*^9}, 3.833629784412005*^9, 3.8336298647878647`*^9, 
   3.833629901980267*^9, {3.833629947594782*^9, 3.833629953545603*^9}, {
   3.833950893850109*^9, 3.833950894215746*^9}, 3.8339523244783573`*^9, {
   3.83397682473665*^9, 3.833976839616523*^9}, {3.83397691040167*^9, 
   3.833976919126761*^9}, {3.833977041477133*^9, 3.833977068852746*^9}, {
   3.833977173709436*^9, 3.833977229774583*^9}, {3.833977408666833*^9, 
   3.833977426208783*^9}, {3.833977526495225*^9, 3.833977549266555*^9}, {
   3.8339776129420033`*^9, 3.8339776314869328`*^9}, {3.8339777463090887`*^9, 
   3.83397777684628*^9}, {3.8378574036712313`*^9, 
   3.837857403789873*^9}},ExpressionUUID->"6c925221-b01e-443c-a023-\
6833ad5dfede"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJzNmXlw1dUVx1McGKaylBRasFKhBougiCCKZbkOUkwbqimpFAmDGcomMBgB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     "], {{
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[0.3], EdgeForm[None], 
        GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgn4V8MXxmfm2hJSVNaUKElCWqVNC+2KohQtFEpKhJCsIRT5J4RUEqLI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           "]], 
          PolygonBox[CompressedData["
1:eJwll3ccl2MUxX/PfVAo7VKiKUqklFBaWtLSIlGJjIxkhBBFIR+jkpWKUEJU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           "]]}]}, {}, {}, {}, {}}, 
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl1He4jmUcwPHXIXuvhnkckq0kRTYdMjtGdbJFtgZRMgqFojJaiKZRaJPV
MNJA9hapSCojSubnd/njc7738zvvud7nee77OsndBqYNyJBIJNL96JAxkRiZ
lEjM5g2Gs58KfExNv6/FKOufqMgn3G5WmyetD1CJT6ljVpenrA9Smc+oZ1af
0dY/U4XFNDBryBjrQ1RlCY3MGjPW+hdu5HPuMEvlaetfuYmlNDFryjPWv1GN
Zdxp1oxx1oe5meU0N2vBeOsjVGcFLc1aMcF6Hrcwn2c5Sg1+51b+YBJ/Uotj
8V74ixc4Hs/N39TnBC/yHw35N56Ts0zlHI35P56T80zjEk25GM9Dwv29pBm1
uSbFs2gmfVmzxDNoZm2tWfUVzaFpml3baE59VfNoO82t7TWvvqYLuIf7SDdL
13Lkp63r6dqBAtaFKBjfx0KzQrSz7qzvMJPOrmfoIq6mveuu+i5zuIa7zV7X
bvSI73Z9v5bnurgf17O0Jx9xPbeZPRF7o8Nib7RM7J0+Hnuuj8Uea+k4Gzo0
zpQOiTOkKXH29NE4szo4zqiWirOtg7SCPqIVNTnuSR/WG/SheDdaUsvqg1pG
B8Y9agktrQO0lPbXFC2uydpPS2hfLanFtLj20aLaW4tpUS2ivfRafSDeixbR
D+jOh/E79rGXPXSJ9+tzhXU3u9hJp9iL2DvdwXa20ZHC5gV0K1vYzL2x/+b5
dBM/sjH2jXzmeXUD6/khzgm5zPPo93zHt9xFNvPcuo5vWEtLrjLPpWtYzSqa
kcE8p37NV3xJEy7E2eZt3iKVNj6bXd9ncjyn6yn6BSs5w+m4h9g/GnCSfzhF
XZ4nzd9ljT2ldjy/6zpak/d4Lt6V2UR9M85iPJvrLDqXEUlX/sdeBpm+lrs=

        "]]}}], {}}, {
    {GrayLevel[0.5], CircleBox[{0, 0}]}, {InsetBox[
      RowBox[{"{", "1", "}"}], {0.27502512499370324, 0.8464402995026866}], 
     InsetBox[
      RowBox[{"{", "2", "}"}], {0.89, 0.}], InsetBox[
      RowBox[{"{", "3", "}"}], {0.27502512499370324, -0.8464402995026866}], 
     InsetBox[
      RowBox[{"{", "4", "}"}], {-0.7200251249937032, -0.5231288745403011}], 
     InsetBox[
      RowBox[{"{", "5", "}"}], {-0.7200251249937032, 0.5231288745403011}]}}},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None, "TransparentPolygonMesh" -> True, "AxesInFront" -> True},
  PlotRange->{{-1.2, 1.2}, {-1.2, 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.6787262032026176`*^9, 3.678726296213449*^9, {3.678726463584597*^9, 
   3.67872649733451*^9}, {3.678726608649984*^9, 3.678726627115292*^9}, {
   3.6787266805436172`*^9, 3.678726730238365*^9}, {3.678726778752643*^9, 
   3.67872681420496*^9}, {3.678726865579506*^9, 3.67872688546828*^9}, 
   3.678726941779839*^9, {3.6787269763966084`*^9, 3.678727103626514*^9}, {
   3.6787273452583723`*^9, 3.6787274019715633`*^9}, {3.6787275195007677`*^9, 
   3.6787275304032993`*^9}, {3.678727612479952*^9, 3.678727658424415*^9}, 
   3.678734915953124*^9, 3.678735112947316*^9, 3.678735248080117*^9, {
   3.678735880537401*^9, 3.678735895320613*^9}, {3.678736012890025*^9, 
   3.678736033436296*^9}, 3.678736125014984*^9, {3.678736225059288*^9, 
   3.6787363187959547`*^9}, 3.6787364506745234`*^9, {3.678736957026966*^9, 
   3.6787369634403553`*^9}, 3.678737021624878*^9, 3.6787370605804977`*^9, 
   3.6787373541313343`*^9, 3.6787378985268803`*^9, 3.678807467384911*^9, 
   3.678809211878869*^9, {3.678809289327898*^9, 3.678809296003249*^9}, 
   3.6788093263198233`*^9, {3.6788100218735943`*^9, 3.678810045280034*^9}, 
   3.678899555820537*^9, 3.680624943176251*^9, 3.721648401529909*^9, 
   3.72216051308881*^9, 3.8336292768116913`*^9, {3.833629406430592*^9, 
   3.833629432490795*^9}, 3.833629528423292*^9, 3.833629561064117*^9, 
   3.833629748779586*^9, 3.833629785750959*^9, 3.8336298658074617`*^9, 
   3.8336299028124647`*^9, 3.8336299545740767`*^9, {3.833950889007213*^9, 
   3.833950894970827*^9}, 3.833952325316119*^9, {3.833976826269553*^9, 
   3.833976840478032*^9}, 3.8339769198396263`*^9, {3.833977042354332*^9, 
   3.8339770694092293`*^9}, {3.8339771764239492`*^9, 
   3.8339772305984297`*^9}, {3.83397752005128*^9, 3.8339775503974333`*^9}, {
   3.8339776150826187`*^9, 3.833977631974444*^9}, {3.833977750555024*^9, 
   3.83397778966566*^9}},
 CellLabel->
  "Out[278]=",ExpressionUUID->"31beb8c8-9fde-4485-96df-7117ff4667bd"],

Cell[BoxData[
 TemplateBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
      GridBox[{{
        "0.9232201497513433`", "0.6375125624968516`", 
         "0.8600125624968515`"}, {
        "0.5`", "0.9450000000000001`", "0.8600125624968515`"}, {
        "0.07677985024865669`", "0.6375125624968516`", 
         "0.36248743750314844`"}, {
        "0.23843556272984945`", "0.1399874375031484`", 
         "0.05500000000000005`"}, {
        "0.7615644372701506`", "0.1399874375031484`", "0.3624874375031484`"}},
        RowSpacings -> 1, ColumnSpacings -> 1, RowAlignments -> Baseline, 
       ColumnAlignments -> Center], "\[NoBreak]", ")"}], 
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\"stats =\""},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {1, 2}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.6787262032026176`*^9, 3.678726296213449*^9, {3.678726463584597*^9, 
   3.67872649733451*^9}, {3.678726608649984*^9, 3.678726627115292*^9}, {
   3.6787266805436172`*^9, 3.678726730238365*^9}, {3.678726778752643*^9, 
   3.67872681420496*^9}, {3.678726865579506*^9, 3.67872688546828*^9}, 
   3.678726941779839*^9, {3.6787269763966084`*^9, 3.678727103626514*^9}, {
   3.6787273452583723`*^9, 3.6787274019715633`*^9}, {3.6787275195007677`*^9, 
   3.6787275304032993`*^9}, {3.678727612479952*^9, 3.678727658424415*^9}, 
   3.678734915953124*^9, 3.678735112947316*^9, 3.678735248080117*^9, {
   3.678735880537401*^9, 3.678735895320613*^9}, {3.678736012890025*^9, 
   3.678736033436296*^9}, 3.678736125014984*^9, {3.678736225059288*^9, 
   3.6787363187959547`*^9}, 3.6787364506745234`*^9, {3.678736957026966*^9, 
   3.6787369634403553`*^9}, 3.678737021624878*^9, 3.6787370605804977`*^9, 
   3.6787373541313343`*^9, 3.6787378985268803`*^9, 3.678807467384911*^9, 
   3.678809211878869*^9, {3.678809289327898*^9, 3.678809296003249*^9}, 
   3.6788093263198233`*^9, {3.6788100218735943`*^9, 3.678810045280034*^9}, 
   3.678899555820537*^9, 3.680624943176251*^9, 3.721648401529909*^9, 
   3.72216051308881*^9, 3.8336292768116913`*^9, {3.833629406430592*^9, 
   3.833629432490795*^9}, 3.833629528423292*^9, 3.833629561064117*^9, 
   3.833629748779586*^9, 3.833629785750959*^9, 3.8336298658074617`*^9, 
   3.8336299028124647`*^9, 3.8336299545740767`*^9, {3.833950889007213*^9, 
   3.833950894970827*^9}, 3.833952325316119*^9, {3.833976826269553*^9, 
   3.833976840478032*^9}, 3.8339769198396263`*^9, {3.833977042354332*^9, 
   3.8339770694092293`*^9}, {3.8339771764239492`*^9, 
   3.8339772305984297`*^9}, {3.83397752005128*^9, 3.8339775503974333`*^9}, {
   3.8339776150826187`*^9, 3.833977631974444*^9}, {3.833977750555024*^9, 
   3.833977789672173*^9}},
 CellLabel->
  "Out[280]=",ExpressionUUID->"ddb199b4-a671-4f3f-9a5a-96728c632338"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "From", " ", "now", " ", "on", " ", "we", " ", "just", " ", "need", " ", 
     "the", " ", "matrix", " ", "stats"}], ",", " ", 
    RowBox[{
    "could", " ", "come", " ", "from", " ", "above", " ", "calculation"}], 
    ",", " ", 
    RowBox[{"or", " ", "from", " ", "experimental", " ", "data"}], ",", " ", 
    "etc"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "m"}], "}"}], "=", 
     RowBox[{"Dimensions", "[", "stats", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Lambda]s", "=", 
     SuperscriptBox["2", "m"]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "The", " ", "hidden", " ", "variable", " ", "gives", " ", "a", " ", 
       "deterministic", " ", "outcome", " ", "to", " ", "every", " ", 
       "measurement"}], ",", " ", 
      RowBox[{"so", " ", "there", " ", "are", " ", 
       SuperscriptBox["2", "m"], " ", "possible", " ", "values"}]}], " ", 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Lambda]for", "[", "meas_", "]"}], ":=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Lambda]", "[", 
           RowBox[{"[", "meas", "]"}], "]"}], "\[Equal]", "1"}], ",", "1", 
         ",", "0"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"Tuples", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", "m"}], "]"}]}], "}"}]}], 
      "]"}]}]}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Gives", " ", "a", " ", "vector", " ", "of", " ", "length", " ", 
      "\[Lambda]s"}], ",", " ", 
     RowBox[{
     "where", " ", "each", " ", "entry", " ", "is", " ", "1", " ", "if", " ", 
      "the", " ", "corresponding", " ", "hidden", " ", "variable", " ", 
      "says", " ", "that", " ", "measurement", " ", "number", " ", "meas", 
      " ", "occurs"}], ",", " ", 
     RowBox[{"and", " ", "0", " ", "otherwise"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"N", ".", "B", "."}], ":", " ", 
      RowBox[{"CDD", " ", "is", " ", "given", " ", 
       RowBox[{"(", "in", ")"}], "equalities", " ", "on", " ", "points", " ", 
       "in", " ", "the", " ", "polytope", " ", "x", " ", "in", " ", "the", 
       " ", "form", " ", "of", " ", "a", " ", "vector", " ", "a"}]}], ",", 
     " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"so", " ", "that", " ", 
           SubscriptBox["a", "0"]}], " ", "+", " ", 
          RowBox[{
           SubscriptBox["a", "1"], 
           SubscriptBox["x", "1"]}], " ", "+", " ", 
          RowBox[{
           SubscriptBox["a", "2"], 
           SubscriptBox["x", "2"]}], " ", "+"}], " ", "..."}], " ", "is"}], 
       " ", "\[GreaterEqual]", 
       RowBox[{"0", " ", "or"}]}], " ", "=", "0"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"norm", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"-", "1"}], "}"}], ",", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"1", ",", "\[Lambda]s"}], "]"}]}], "]"}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"Normalization", " ", 
       RowBox[{"equality", ":", " ", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{
          SubscriptBox["\[Sum]", "\[Lambda]"], 
          RowBox[{"prob", 
           RowBox[{"(", "\[Lambda]", ")"}]}]}]}]}]}], " ", "=", " ", "0"}], 
     " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"pos", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "0", "}"}], ",", "#"}], "]"}], "&"}], "/@", 
      RowBox[{"IdentityMatrix", "[", "\[Lambda]s", "]"}]}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"Positivity", " ", 
       RowBox[{"inequality", ":", " ", 
        RowBox[{"for", " ", "each", " ", "\[Lambda]"}]}]}], ",", " ", 
      RowBox[{
       RowBox[{"prob", 
        RowBox[{"(", "\[Lambda]", ")"}]}], " ", "\[GreaterEqual]", " ", 
       "0"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"reproduce", "[", "stat_", "]"}], ":=", 
     RowBox[{"MapIndexed", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"-", "#1"}], "}"}], ",", 
          RowBox[{"\[Lambda]for", "[", 
           RowBox[{"#2", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], "&"}], ",", 
       "stat"}], "]"}]}]}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Equality", " ", "of", " ", "reproducing", " ", "the", " ", 
      "operational", " ", "statistics", " ", "in", " ", 
      RowBox[{"stat", ":", " ", 
       RowBox[{"for", " ", "each", " ", "measurement", " ", "i"}]}]}], ",", 
     " ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["stat", "i"]}], " ", "+", " ", 
       RowBox[{
        SubscriptBox["\[Sum]", 
         RowBox[{"\[Lambda]", " ", "\[Element]", " ", 
          RowBox[{"\[Lambda]for", 
           RowBox[{"(", "i", ")"}]}]}]], 
        RowBox[{"prob", 
         RowBox[{"(", "\[Lambda]", ")"}]}]}]}], " ", "=", " ", "0"}]}], " ", 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"N", ".", "B", "."}], ":", " ", 
     RowBox[{"cddHtoV", " ", "takes", " ", "two", " ", 
      RowBox[{"arguments", ":", " ", 
       RowBox[{
       "a", " ", "list", " ", "of", " ", "equalities", " ", "and", " ", "a", 
        " ", "list", " ", "of", " ", 
        RowBox[{"inequalities", ".", " ", "It"}], " ", "returns", " ", "a", 
        " ", "list", " ", "of", " ", "extreme", " ", "points"}]}]}]}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"poly", "[", "stat_", "]"}], ":=", 
    RowBox[{"cddHtoV", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", "norm", "}"}], ",", 
        RowBox[{"reproduce", "[", "stat", "]"}]}], "]"}], ",", "pos"}], 
     "]"}]}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Use", " ", "CDD", " ", "to", " ", "find", " ", "extreme", " ", "points",
       " ", "of", " ", "polytope", " ", "of", " ", "hidden"}], "-", 
     RowBox[{
     "variable", " ", "distributions", " ", "that", " ", "reproduce", " ", 
      "stat"}]}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Consider", " ", "two", " ", "polytopes", " ", "with", " ", "lists", " ",
       "of", " ", "vertices", " ", "v1", " ", "and", " ", "v2", 
      "\[IndentingNewLine]", "If", " ", "they", " ", "do", " ", "not", " ", 
      "intersect"}], ",", " ", 
     RowBox[{
     "then", " ", "there", " ", "exists", " ", "a", " ", "gap", " ", 
      "between", " ", "them"}], ",", " ", 
     RowBox[{
      RowBox[{"i", ".", "e", ".", " ", "there"}], " ", "exists", " ", "x"}], 
     ",", " ", "c1", ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"c2", " ", "with", " ", 
        RowBox[{"v", ".", "x"}]}], " ", "\[LessEqual]", " ", 
       RowBox[{"c1", " ", "for", " ", "all", " ", "v"}]}], " ", "\[Element]", 
      " ", 
      RowBox[{
       RowBox[{"v1", " ", "whereas", " ", 
        RowBox[{"v", ".", "x"}]}], " ", "\[GreaterEqual]", " ", 
       RowBox[{"c2", " ", "for", " ", "all", " ", "v"}]}], " ", "\[Element]", 
      " ", "v2"}], ",", " ", 
     RowBox[{
      RowBox[{"and", " ", "c1"}], " ", "<", " ", 
      RowBox[{
       RowBox[{"c2", ".", "\[IndentingNewLine]", "Here"}], " ", "this", " ", 
       "is", " ", "implemented", " ", "as", " ", "a", " ", "linear", " ", 
       RowBox[{"program", ":", " ", 
        RowBox[{
         RowBox[{"the", " ", "first", " ", "variable", " ", "is", " ", "c1"}],
          " ", "-", " ", "c2"}]}]}]}], ",", " ", 
     RowBox[{
      RowBox[{
      "which", " ", "is", " ", "minimized", "\[IndentingNewLine]", "The", " ",
        "second", " ", "variable", " ", "is", " ", "c1", 
       "\[IndentingNewLine]", "The", " ", "remaining", " ", "variables", " ", 
       "are", " ", "x", "\[IndentingNewLine]", "To", " ", "ensure", " ", 
       "the", " ", "problem", " ", "always", " ", "has", " ", "a", " ", 
       "bounded", " ", "solutino", " ", "we", " ", "require", " ", "the", " ",
        "first", " ", "variable", " ", "is"}], " ", "\[GreaterEqual]", " ", 
      RowBox[{
       RowBox[{"-", "1"}], "\[IndentingNewLine]", "If", " ", "the", " ", 
       "polytopes", " ", "do", " ", "intersect"}]}], ",", " ", 
     RowBox[{
      RowBox[{"then", " ", "c1"}], " ", "\[GreaterEqual]", " ", 
      RowBox[{
      "c2", " ", "and", " ", "so", " ", "the", " ", "first", " ", "variable", 
       " ", "is", " ", 
       RowBox[{"positive", ".", " ", "In"}], " ", "this", " ", "case", " ", 
       "the", " ", "minimum", " ", "value", " ", "is", " ", "0"}]}], ",", " ", 
     RowBox[{
     "because", " ", "we", " ", "can", " ", "always", " ", "set", " ", "c1"}],
      ",", " ", 
     RowBox[{"c2", " ", "and", " ", "x", " ", "to", " ", 
      RowBox[{"zero", "."}]}]}], "\[IndentingNewLine]", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"intersection", "[", 
     RowBox[{"v1_", ",", "v2_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"one1", ",", "one2"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"one1", "=", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Length", "[", "v1", "]"}], ",", "1"}], "}"}]}], "]"}]}], 
       ";", 
       RowBox[{"one2", "=", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Length", "[", "v2", "]"}], ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"LinearProgramming", "[", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", 
           RowBox[{"ConstantArray", "[", 
            RowBox[{"0", ",", 
             RowBox[{"\[Lambda]s", "+", "1"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"ArrayFlatten", "[", GridBox[{
            {
             RowBox[{"0", "one1"}], "one1", 
             RowBox[{"-", "v1"}]},
            {"one2", 
             RowBox[{"-", "one2"}], "v2"}
           }], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"0", GridBox[{
             {"one1"},
             {"one2"}
            }]}], "]"}], ",", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"-", "1"}], "}"}], ",", 
           RowBox[{"ConstantArray", "[", 
            RowBox[{
             RowBox[{"-", "\[Infinity]"}], ",", 
             RowBox[{"\[Lambda]s", "+", "1"}]}], "]"}]}], "]"}]}], "]"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"intersects", "[", 
     RowBox[{"v1_", ",", "v2_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"intersection", "[", 
        RowBox[{"v1", ",", "v2"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}], "==", "0"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6786412402985563`*^9, 3.6786412867272778`*^9}, {
   3.678641332870533*^9, 3.678641387286252*^9}, {3.678641426989182*^9, 
   3.678641687776697*^9}, {3.6786417642389593`*^9, 3.6786417652952347`*^9}, 
   3.6787236956168947`*^9, {3.67872403843979*^9, 3.678724040898107*^9}, {
   3.678724507506617*^9, 3.678724550353632*^9}, {3.6787246825994043`*^9, 
   3.678724814029642*^9}, {3.6787249253799553`*^9, 3.6787249478027487`*^9}, {
   3.678725061994008*^9, 3.678725067537773*^9}, {3.678726054609026*^9, 
   3.67872606631946*^9}, {3.6787268961550713`*^9, 3.678726917585931*^9}, {
   3.6787272356367407`*^9, 3.678727255147286*^9}, {3.6787272998464947`*^9, 
   3.678727300122299*^9}, {3.678733205167592*^9, 3.678733205349958*^9}, {
   3.678734880610639*^9, 3.678734881010683*^9}, {3.678807559551998*^9, 
   3.6788076568870687`*^9}, {3.678807706773967*^9, 3.6788077280942907`*^9}, {
   3.678807760702519*^9, 3.6788077693261557`*^9}, 3.678807814029847*^9, {
   3.678808029756941*^9, 3.678808127212356*^9}, {3.678808183340035*^9, 
   3.678808343418827*^9}, {3.678808523338606*^9, 3.6788085379543858`*^9}, {
   3.678808595441127*^9, 3.678808622064507*^9}, {3.678808688265071*^9, 
   3.678808694344439*^9}, {3.67880899767983*^9, 3.678809020719187*^9}, {
   3.678809088159061*^9, 3.6788091887972937`*^9}, {3.678809237925541*^9, 
   3.6788092412372017`*^9}, {3.67880935374998*^9, 3.678809379436789*^9}, {
   3.7216485322213383`*^9, 3.721648595229849*^9}, {3.7216487003254585`*^9, 
   3.721648744520336*^9}, {3.7216487749275923`*^9, 3.7216488098560534`*^9}, {
   3.721648850088524*^9, 3.7216488642845488`*^9}, {3.721648966870329*^9, 
   3.721648975809145*^9}, {3.7216491030429683`*^9, 3.7216491640702753`*^9}, {
   3.721649549765911*^9, 3.7216495515755143`*^9}, {3.721650096117175*^9, 
   3.7216502277502065`*^9}, {3.721651737456421*^9, 3.7216517445856333`*^9}, {
   3.7216517960501237`*^9, 3.721651800168531*^9}, {3.7216521852787113`*^9, 
   3.7216522449176164`*^9}, {3.721652418624922*^9, 3.721652431338944*^9}, {
   3.7216526931864038`*^9, 3.721652747349699*^9}, {3.7216527992353897`*^9, 
   3.721652799999791*^9}, {3.7216545920806828`*^9, 3.721654694199462*^9}, 
   3.7221598865449095`*^9, {3.7221605791081257`*^9, 3.722160580215728*^9}, {
   3.7221610065498486`*^9, 3.722161011079857*^9}, {3.722161155973796*^9, 
   3.7221613254690933`*^9}, {3.7221614632037354`*^9, 3.722161540299071*^9}, {
   3.722161606511304*^9, 3.7221616409717646`*^9}, {3.7221617859760194`*^9, 
   3.7221617895484257`*^9}, {3.7221619091850357`*^9, 
   3.7221619461415005`*^9}, {3.722162001755598*^9, 3.7221620218640337`*^9}, {
   3.7221620605989017`*^9, 3.7221622751012783`*^9}, {3.833977352658883*^9, 
   3.833977368262746*^9}, {3.833977446726511*^9, 3.833977471267626*^9}, {
   3.833977513888198*^9, 3.833977516502213*^9}, {3.833977826028131*^9, 
   3.8339778702911663`*^9}},ExpressionUUID->"6ff16a1d-6b4c-48e3-a6f4-\
9083d05c3ba2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "all", " ", "pairs", " ", "of", " ", "disjoint", " ", 
    "subsets", " ", "of", " ", "states", " ", "with", " ", "size", " ", "at", 
    " ", "least", " ", "2"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"pointidxs", "=", 
     RowBox[{"Range", "[", "n", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pairidxs", "=", 
     RowBox[{"DeleteDuplicates", "[", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Sort", "[", 
             RowBox[{"{", 
              RowBox[{"x", ",", "#"}], "}"}], "]"}], "&"}], "/@", 
           RowBox[{"Subsets", "[", 
            RowBox[{
             RowBox[{"Complement", "[", 
              RowBox[{"pointidxs", ",", "x"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"2", ",", "n"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"Subsets", "[", 
             RowBox[{"pointidxs", ",", 
              RowBox[{"{", 
               RowBox[{"2", ",", 
                RowBox[{"n", "-", "2"}]}], "}"}]}], "]"}]}], "}"}]}], "]"}], 
        ",", "1"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.678725069475506*^9, 3.6787251076479597`*^9}, {
  3.678725175142891*^9, 3.6787252374220133`*^9}, {3.678725276551607*^9, 
  3.678725401891096*^9}, {3.678725475507704*^9, 3.6787254859865723`*^9}, {
  3.7221663239129934`*^9, 3.7221663587010546`*^9}},
 CellLabel->
  "In[232]:=",ExpressionUUID->"bb71615f-c6bb-4fce-a120-c14c4e1aefa5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "the", " ", "polytope", " ", "for", " ", "each", " ", "state",
     " ", "using", " ", "cdd"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"polys", "=", 
    RowBox[{"poly", "/@", "stats"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.678724294917939*^9, 3.678724330733556*^9}, {
   3.6787254889058743`*^9, 3.678725498025304*^9}, {3.6787269323975353`*^9, 
   3.6787269338888702`*^9}, 3.678733296340657*^9, 3.6787348848258343`*^9, {
   3.722169633969141*^9, 3.7221696527983737`*^9}, {3.8339522569056377`*^9, 
   3.8339522662237463`*^9}},
 CellLabel->
  "In[281]:=",ExpressionUUID->"b55d1105-d23f-432e-a7a4-bcaef7efaad8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "For", " ", "each", " ", "pair", " ", "of", " ", "subsets", " ", "of", 
     " ", "states"}], ",", " ", 
    RowBox[{
    "figure", " ", "out", " ", "if", " ", "the", " ", "convex", " ", "hull", 
     " ", "of", " ", "their", " ", "polytopes", " ", 
     RowBox[{"intersect", ".", " ", "If"}], " ", "they", " ", "intersect"}], 
    ",", " ", 
    RowBox[{
    "then", " ", "there", " ", "exists", " ", "a", " ", "mixture", " ", "of", 
     " ", "each", " ", "subset", " ", "that", " ", "can", " ", "be", " ", 
     "represented", " ", "by", " ", "the", " ", "same", " ", "distribution", 
     " ", "over", " ", "hidden", " ", 
     RowBox[{"variables", ".", " ", "For"}], " ", "all", " ", "we", " ", 
     "know"}], ",", " ", 
    RowBox[{
    "this", " ", "might", " ", "be", " ", "the", " ", "only", " ", "mixture", 
     " ", "that", " ", "gives", " ", "the", " ", "same", " ", "operational", 
     " ", "probabilities", " ", "for", " ", "the", " ", "unknown", " ", 
     "additional", " ", 
     RowBox[{"measurements", ".", " ", "Hence"}], " ", "we", " ", "cannot", 
     " ", "prove", " ", "preparation", " ", 
     RowBox[{"contextuality", ".", " ", "So"}], " ", 
     RowBox[{"we", "'"}], "re", " ", "hoping", " ", "to", " ", "get", " ", 
     "all", " ", 
     RowBox[{"False", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"result", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"intersects", "[", 
       RowBox[{
        RowBox[{"Join", "@@", 
         RowBox[{"polys", "[", 
          RowBox[{"[", "#1", "]"}], "]"}]}], ",", 
        RowBox[{"Join", "@@", 
         RowBox[{"polys", "[", 
          RowBox[{"[", "#2", "]"}], "]"}]}]}], "]"}], "&"}], "@@@", 
     "pairidxs"}]}], "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Or", "@@", "result"}], ",", 
     "\"\<I could not determine whether there is a noncontextual model\>\"", 
     ",", "\"\<The proof of contextuality is robust\>\""}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.678808572713065*^9, 3.6788085738567877`*^9}, {
  3.722169678491619*^9, 3.7221696793808203`*^9}, {3.7221697137164807`*^9, 
  3.7221697864906087`*^9}, {3.7221707354383345`*^9, 3.72217084098812*^9}, {
  3.722171388741065*^9, 3.7221713898174667`*^9}, {3.833630572220867*^9, 
  3.833630572995879*^9}, {3.8339522390969553`*^9, 3.8339522444149437`*^9}, {
  3.833976314469288*^9, 3.833976327500041*^9}, {3.833977083955318*^9, 
  3.833977148719852*^9}},
 CellLabel->
  "In[282]:=",ExpressionUUID->"0a3e995e-144f-4053-9a41-a58d2a42c641"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False", ",", 
   "False", ",", "False", ",", "False", ",", "False", ",", "False"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.833629450269218*^9, 3.833629539283787*^9, 3.833629583049109*^9, 
   3.8336297611222267`*^9, 3.833629793942603*^9, {3.83362988681878*^9, 
   3.8336299129510603`*^9}, 3.833630570077845*^9, {3.833950915628269*^9, 
   3.833950918052795*^9}, 3.8339522457173634`*^9, 3.833952334935979*^9, {
   3.8339763007663603`*^9, 3.8339763047176943`*^9}, 3.8339763365046577`*^9, 
   3.833976864434658*^9, 3.83397701780042*^9, {3.833977049877787*^9, 
   3.8339770936956673`*^9}, 3.833977149263549*^9, {3.8339771871078463`*^9, 
   3.83397723872406*^9}, 3.833977815012012*^9},
 CellLabel->
  "Out[282]=",ExpressionUUID->"340698a8-5034-48b8-805f-eee6ebd106ba"],

Cell[BoxData["\<\"The proof of contextuality is robust\"\>"], "Output",
 CellChangeTimes->{
  3.833629450269218*^9, 3.833629539283787*^9, 3.833629583049109*^9, 
   3.8336297611222267`*^9, 3.833629793942603*^9, {3.83362988681878*^9, 
   3.8336299129510603`*^9}, 3.833630570077845*^9, {3.833950915628269*^9, 
   3.833950918052795*^9}, 3.8339522457173634`*^9, 3.833952334935979*^9, {
   3.8339763007663603`*^9, 3.8339763047176943`*^9}, 3.8339763365046577`*^9, 
   3.833976864434658*^9, 3.83397701780042*^9, {3.833977049877787*^9, 
   3.8339770936956673`*^9}, 3.833977149263549*^9, {3.8339771871078463`*^9, 
   3.83397723872406*^9}, 3.8339778150140944`*^9},
 CellLabel->
  "Out[283]=",ExpressionUUID->"932a9f12-6e53-421c-b968-da2d80e6323e"]
}, Open  ]]
},
PrintingStyleEnvironment->"Working",
WindowSize->{1440., 795.75},
WindowMargins->{{0, Automatic}, {0, Automatic}},
WindowStatusArea->"intersecting_polytopes_v2.nb last backed up to \
intersecting_polytopes_v2.nb~ on Fri 19 Aug 2016 at 3:49:02 PM",
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperOrientation"->"Portrait",
"PaperSize"->{594.75, 842.25},
"PostScriptOutputFile"->"/home/mattrix/print.pdf"},
SpellingDictionaries->{"CorrectWords"->{
 "Contextuality", "tomographically", "L\[IAcute]dia", "Bettina", 
  "sublicense"}},
FrontEndVersion->"12.1 for Linux x86 (64-bit) (March 18, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"68b66c6d-7702-4f39-a027-7035e98060eb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 2328, 39, 128, "Text",ExpressionUUID->"371bfb14-4a9c-465e-b223-79a5729a2fe7"],
Cell[CellGroupData[{
Cell[2911, 63, 6714, 154, 247, "Input",ExpressionUUID->"6c925221-b01e-443c-a023-6833ad5dfede"],
Cell[9628, 219, 17830, 308, 370, "Output",ExpressionUUID->"31beb8c8-9fde-4485-96df-7117ff4667bd"],
Cell[27461, 529, 3317, 60, 101, "Output",ExpressionUUID->"ddb199b4-a671-4f3f-9a5a-96728c632338"]
}, Open  ]],
Cell[30793, 592, 14388, 338, 590, "Input",ExpressionUUID->"6ff16a1d-6b4c-48e3-a6f4-9083d05c3ba2"],
Cell[45184, 932, 1672, 42, 70, "Input",ExpressionUUID->"bb71615f-c6bb-4fce-a120-c14c4e1aefa5"],
Cell[46859, 976, 708, 15, 50, "Input",ExpressionUUID->"b55d1105-d23f-432e-a7a4-bcaef7efaad8"],
Cell[CellGroupData[{
Cell[47592, 995, 2608, 57, 133, "Input",ExpressionUUID->"0a3e995e-144f-4053-9a41-a58d2a42c641"],
Cell[50203, 1054, 1088, 19, 32, "Output",ExpressionUUID->"340698a8-5034-48b8-805f-eee6ebd106ba"],
Cell[51294, 1075, 736, 11, 32, "Output",ExpressionUUID->"932a9f12-6e53-421c-b968-da2d80e6323e"]
}, Open  ]]
}
]
*)

